@@ -30,7 +30,7 @@ GetOptions(
 $repo       or do { warn "Missing mandatory option: --repo\n\n"; pod2usage() };
 $server_url or do { warn "Missing mandatory option: --server_url\n\n"; pod2usage() };
 $branch='master' unless $branch;
-die "Bad branch name: $branch" unless $branch =~ /^[A-Za-z0-9._-]+$/; # guard from web
+die "Bad branch name: $branch" unless $branch =~ m{^[A-Za-z0-9./_-]+$}; # guard from web
 $server_url =~ s!/$!! if defined $server_url;
 
 my $app = Ukigumo::Client->new(
